@@ -1,18 +1,7 @@
 /*
- * Copyright 2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2017 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef ELISAAPPLICATION_H
@@ -23,6 +12,7 @@
 #include "config-upnp-qt.h"
 
 #include "elisautils.h"
+#include "datatypes.h"
 
 #include <QObject>
 #include <QString>
@@ -38,7 +28,7 @@ class AudioWrapper;
 class ManageAudioPlayer;
 class ManageMediaPlayerControl;
 class ManageHeaderBar;
-class QQmlApplicationEngine;
+class QQmlEngine;
 class ElisaApplicationPrivate;
 class QSessionManager;
 
@@ -47,11 +37,15 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
 
     Q_OBJECT
 
-    Q_PROPERTY(ElisaUtils::EntryDataList arguments
+    Q_PROPERTY(DataTypes::EntryDataList arguments
                READ arguments
                WRITE setArguments
                NOTIFY argumentsChanged)
 
+    Q_PROPERTY(ElisaUtils::PlayListEntryType embeddedView
+               READ embeddedView
+               NOTIFY embeddedViewChanged)
+
     Q_PROPERTY(MusicListenersManager *musicManager
                READ musicManager
                NOTIFY musicManagerChanged)
@@ -103,7 +97,7 @@ public:
 
     bool eventFilter(QObject *object, QEvent *event) override;
 
-    const ElisaUtils::EntryDataList &arguments() const;
+    const DataTypes::EntryDataList &arguments() const;
 
     MusicListenersManager *musicManager() const;
 
@@ -123,6 +117,8 @@ public:
 
     bool showSystemTrayIcon() const;
 
+    ElisaUtils::PlayListEntryType embeddedView() const;
+
 Q_SIGNALS:
 
     void argumentsChanged();
@@ -141,8 +137,7 @@ Q_SIGNALS:
 
     void manageHeaderBarChanged();
 
-    void enqueue(const ElisaUtils::EntryDataList &newEntries,
-                 ElisaUtils::PlayListEntryType databaseIdType,
+    void enqueue(const DataTypes::EntryDataList &newEntries,
                  ElisaUtils::PlayListEnqueueMode enqueueMode,
                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
@@ -154,6 +149,8 @@ Q_SIGNALS:
 
     void commitDataRequest(QSessionManager &manager);
 
+    void embeddedViewChanged();
+
 public Q_SLOTS:
 
     void appHelpActivated();
@@ -166,7 +163,7 @@ public Q_SLOTS:
 
     void configureElisa();
 
-    void setArguments(const ElisaUtils::EntryDataList &newArguments);
+    void setArguments(const DataTypes::EntryDataList &newArguments);
 
     void activateActionRequested(const QString &actionName, const QVariant &parameter);
 
@@ -178,7 +175,7 @@ public Q_SLOTS:
 
 public:
 
-    void setQmlEngine(QQmlApplicationEngine *engine);
+    void setQmlEngine(QQmlEngine *engine);
 
 private Q_SLOTS:
 
@@ -204,7 +201,7 @@ private:
 
     void setupActions(const QString &actionName);
 
-    ElisaUtils::EntryDataList checkFileListAndMakeAbsolute(const ElisaUtils::EntryDataList &filesList,
+    DataTypes::EntryDataList checkFileListAndMakeAbsolute(const DataTypes::EntryDataList &filesList,
                                                               const QString &workingDirectory) const;
 
     std::unique_ptr<ElisaApplicationPrivate> d;
