@@ -1,18 +1,7 @@
 /*
- * Copyright 2018 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2018 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "modeldataloader.h"
@@ -115,6 +104,7 @@ void ModelDataLoader::loadData(ElisaUtils::PlayListEntryType dataType)
         break;
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
+    case ElisaUtils::Container:
         break;
     case ElisaUtils::Radio:
         Q_EMIT allRadiosData(d->mDatabase->allRadiosData());
@@ -149,6 +139,7 @@ void ModelDataLoader::loadDataByAlbumId(ElisaUtils::PlayListEntryType dataType,
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -175,6 +166,7 @@ void ModelDataLoader::loadDataByGenre(ElisaUtils::PlayListEntryType dataType, co
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -201,6 +193,7 @@ void ModelDataLoader::loadDataByArtist(ElisaUtils::PlayListEntryType dataType, c
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -228,6 +221,7 @@ void ModelDataLoader::loadDataByGenreAndArtist(ElisaUtils::PlayListEntryType dat
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -257,6 +251,7 @@ void ModelDataLoader::loadDataByDatabaseIdAndUrl(ElisaUtils::PlayListEntryType d
     case ElisaUtils::Lyricist:
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -300,6 +295,7 @@ void ModelDataLoader::loadDataByUrl(ElisaUtils::PlayListEntryType dataType, cons
     case ElisaUtils::Genre:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Unknown:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -325,6 +321,7 @@ void ModelDataLoader::loadRecentlyPlayedData(ElisaUtils::PlayListEntryType dataT
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -350,6 +347,7 @@ void ModelDataLoader::loadFrequentlyPlayedData(ElisaUtils::PlayListEntryType dat
     case ElisaUtils::FileName:
     case ElisaUtils::Unknown:
     case ElisaUtils::Radio:
+    case ElisaUtils::Container:
         break;
     }
 }
@@ -376,6 +374,7 @@ void ModelDataLoader::databaseTracksAdded(const ListTrackDataType &newData)
     case ModelDataLoader::FilterType::FilterByArtist:
     case ModelDataLoader::FilterType::FilterByRecentlyPlayed:
     case ModelDataLoader::FilterType::FilterByFrequentlyPlayed:
+    case ModelDataLoader::FilterType::FilterByPath:
     case ModelDataLoader::FilterType::UnknownFilter:
         break;
     }
@@ -403,6 +402,7 @@ void ModelDataLoader::databaseArtistsAdded(const ListArtistDataType &newData)
     case ModelDataLoader::FilterType::FilterById:
     case ModelDataLoader::FilterType::FilterByRecentlyPlayed:
     case ModelDataLoader::FilterType::FilterByFrequentlyPlayed:
+    case ModelDataLoader::FilterType::FilterByPath:
     case ModelDataLoader::FilterType::UnknownFilter:
         break;
     }
@@ -443,12 +443,13 @@ void ModelDataLoader::databaseAlbumsAdded(const ListAlbumDataType &newData)
     case ModelDataLoader::FilterType::FilterById:
     case ModelDataLoader::FilterType::FilterByRecentlyPlayed:
     case ModelDataLoader::FilterType::FilterByFrequentlyPlayed:
+    case ModelDataLoader::FilterType::FilterByPath:
     case ModelDataLoader::FilterType::UnknownFilter:
         break;
     }
 }
 
-void ModelDataLoader::updateFileMetaData(const TrackDataType &trackDataType, const QUrl &url)
+void ModelDataLoader::updateFileMetaData(const DataTypes::TrackDataType &trackDataType, const QUrl &url)
 {
     d->mFileWriter.writeAllMetaDataToFile(url, trackDataType);
 }
